==> IPLock-0.4.tar.gz: IPLock-0.4/lang/ext/fr_FR.php <==
<?php
$lang['friendlyname'] = 'Blocage d&#039;IP';
$lang['postinstall'] = 'L&#039;installation d&#039;IPLock est un succ&egrave;s';
$lang['manage'] = 'Gestion d&#039;IPLock';
$lang['preuninstall'] = 'La liste des IP autoris&eacute;e sera d&eacute;truite. &Ecirc;tes-vous sur de vouloir d&eacute;sinstaller IPLock ?';
$lang['postuninstall'] = 'La d&eacute;sinstallation d&#039;IPLock est un succ&egrave;s';
$lang['moddescription'] = 'Ce module permet de g&eacute;rer la liste des IP autoris&eacute;es &agrave; se connecter sur l&#039;interface administrateur du site.';
$lang['installed'] = 'Module version %s install&eacute;';
$lang['uninstalled'] = 'Module version %s d&eacute;sinstall&eacute;';
$lang['note'] = 'Note ';
$lang['general_pane_title'] = 'Param&egrave;tres g&eacute;n&eacute;raux';
$lang['default_process'] = 'R&eacute;glage du mode de fonctionnement par d&eacute;fault de IPLock ';
$lang['process_example_all'] = 'En mode &quot;Autoriser &agrave; tous&quot;, toutes les IPs sont autoris&eacute;es par d&eacute;fault &agrave; se connecter &agrave; l&#039;interface admin.';
$lang['process_example_only'] = 'En mode &quot;Interdire &agrave; tous&quot;, la seule IP autoris&eacute;e par d&eacute;fault &agrave; se connecter &agrave; l&#039;interface admin est 127.0.0.1. ';
$lang['allow_all'] = 'Autoriser &agrave; tous';
$lang['deny_all'] = 'Interdire &agrave; tous';
$lang['connection_limit'] = 'Limite de connexion  ';
$lang['connection_limit_description'] = 'Nombre de tentative de connexion par minute (minimum 0). <br />Si la limite est d&eacute;pass&eacute;e, l&#039;IP de l&#039;utilisateur sera bannie.';
$lang['notification_explanation'] = 'Afficher une notification, lorsque quelqu&#039;un se fait bannir ?';
$lang['authorized_ip_explanation'] = 'Cette liste est utilis&eacute;e au cas o&ugrave; IPLock fonctionne en mode &quot;Interdire &agrave; tous&quot;.';
$lang['authorized_ip_legend'] = 'Liste des IPs autoris&eacute;es express&eacute;ment';
$lang['add_ip_legend'] = 'Ajouter une nouvelle IP (ou plage) aux exceptions';
$lang['add_current_ip'] = 'Ou ajoutez votre adresse IP actuelle (%s)';
$lang['ip_comment'] = 'Commentaires';
$lang['syntax_legend'] = 'Syntaxe';
$lang['syntax_intro'] = 'Une IP se d&eacute;compose en quatre nombre variant de 0 &agrave; 255. Pour chacun de ces nombres, on peut sp&eacute;cifier :';
$lang['syntax_line1'] = 'Une valeur fixe, entre 0 et 255';
$lang['syntax_line2'] = 'Un plage, en tapant &#039;12-245&#039; par exemple';
$lang['syntax_line3'] = 'Tout nombre accept&eacute;, en tapant &#039;*&#039;';
$lang['prohibited_ip_explanation'] = 'Cette liste est utilis&eacute;e quelque soit le mode. Une IP interdite sera toujours interdite.';
$lang['prohibited_ip_legend'] = 'Liste des IPs interdites express&eacute;ment';
$lang['banned_template'] = 'Template de la page  &quot;Banni&quot;';
$lang['banned_template_legend'] = 'Modifiez le template comme vous le d&eacute;sirez.';
$lang['edit_ip_comment_legend'] = 'R&eacute;digez un commentaire pour l&#039;IP %s';
$lang['help'] = '<h3>Que fait ce module ?</h3>
<p>IPLock filtre les adresses IP ayant le droit de se connecter sur l&#039;interface Admin</p>
<h3>Comment l&#039;utiliser ?</h3>
<p>Apr&egrave;s installation, vous pouvez acc&eacute;der au module IPLock par le panneau d&#039;administration sous le menu &quot;Administration du site&quot;.
Son fonctionnement est pour le reste relativement &eacute;vident, je l&#039;esp&egrave;re</p>
<h3>Permissions</h3>
<p>IPLock ajoute une permission, &quot;Gestion d&#039;IPLock&quot;, et il est n&eacute;cessaire qu&#039;elle soit coch&eacute;e pour pouvoir administrer le blocage d&#039;IP</p>
<h3>Copyright et Licence</h3>
<p>Copyright &amp;copy; 2010, Beno&icirc;t Vermont <a href="mailto:redwarp@gmail.com">&amp;lt;redwarp@gmail.com&amp;gt;</a>. Tous droits r&eacute;serv&eacute;s.</p>
<p>Ce module est distribu&eacute; sous la licence <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. Vous devez agr&eacute;er aux termes de cette licence pour pouvoir utiliser ce module.</p>';
$lang['accessdenied'] = '<h3>Acc&egrave;s refus&eacute;</h3>
<p>&Ecirc;tes vous s&ucirc;r de poss&eacute;der les droits suffisant ? Si oui, contactez votre administrateur afin
qu&#039;il corrige le probl&egrave;me</p>';
$lang['genericerror'] = 'Hohoho. Il semblerai que votre derni&egrave;re op&eacute;ration ai g&eacute;n&eacute;r&eacute; une erreur. &Ecirc;tes vous s&ucirc;rs d&#039;avoir tout fait correctement ?';
$lang['iperror'] = 'L&#039;IP sp&eacute;cifi&eacute;e n&#039;est pas valide.';
$lang['delete'] = 'Supprimer';
$lang['edit'] = 'Editer le commentaire';
$lang['cancel'] = 'Annuler';
$lang['deleteconfirm'] = 'Confirmez la suppression';
$lang['emptylist'] = 'La liste est vide';
$lang['wrongip'] = '%s : IP non autoris&eacute;e';
$lang['add'] = 'Ajouter';
$lang['added_allowed_ip'] = '%s : IP autoris&eacute;e';
$lang['added_denied_ip'] = '%s : IP bannie';
$lang['removed_ip'] = '%s : IP supprim&eacute;e';
$lang['prefs'] = 'Pr&eacute;f&eacute;rences';
$lang['allowed_ip'] = 'IPs autoris&eacute;es';
$lang['denied_ip'] = 'IPs bannies';
$lang['yes'] = 'Oui';
$lang['no'] = 'Non';
$lang['save'] = 'Enregistrer les modifications';
$lang['notification_message'] = 'Quelqu&#039;un s&#039;est fait bannir en se trompant d&#039;identifiants. Visitez le panneau d&#039;administration %s pour effacer cette notification.';
$lang['qca'] = 'P0-213506652-1273430421057';
$lang['utmz'] = '156861353.1273444543.3.2.utmccn=(organic)|utmcsr=google|utmctr=cmsmadesimple friendly name module|utmcmd=organic';
$lang['utma'] = '156861353.151021572.1273430421.1273527926.1273791653.7';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1273791653';
?>

==> IPLock-0.4.1.tar.gz: IPLock-0.4.1/lang/ext/fr_FR.php <==
<?php
$lang['friendlyname'] = 'Blocage d&#039;IP';
$lang['postinstall'] = 'L&#039;installation d&#039;IPLock est un succ&egrave;s';
$lang['manage'] = 'Gestion d&#039;IPLock';
$lang['preuninstall'] = 'La liste des IP autoris&eacute;e sera d&eacute;truite. &Ecirc;tes-vous sur de vouloir d&eacute;sinstaller IPLock ?';
$lang['postuninstall'] = 'La d&eacute;sinstallation d&#039;IPLock est un succ&egrave;s';
$lang['moddescription'] = 'Ce module permet de g&eacute;rer la liste des IP autoris&eacute;es &agrave; se connecter sur l&#039;interface administrateur du site.';
$lang['installed'] = 'Module version %s install&eacute;';
$lang['uninstalled'] = 'Module version %s d&eacute;sinstall&eacute;';
$lang['note'] = 'Note ';
$lang['general_pane_title'] = 'Param&egrave;tres g&eacute;n&eacute;raux';
$lang['default_process'] = 'R&eacute;glage du mode de fonctionnement par d&eacute;fault de IPLock ';
$lang['process_example_all'] = 'En mode &quot;Autoriser &agrave; tous&quot;, toutes les IPs sont autoris&eacute;es par d&eacute;fault &agrave; se connecter &agrave; l&#039;interface admin.';
$lang['process_example_only'] = 'En mode &quot;Interdire &agrave; tous&quot;, la seule IP autoris&eacute;e par d&eacute;fault &agrave; se connecter &agrave; l&#039;interface admin est 127.0.0.1. ';
$lang['allow_all'] = 'Autoriser &agrave; tous';
$lang['deny_all'] = 'Interdire &agrave; tous';
$lang['connection_limit'] = 'Limite de connexion  ';
$lang['connection_limit_description'] = 'Nombre de tentative de connexion par minute (minimum 0). <br />Si la limite est d&eacute;pass&eacute;e, l&#039;IP de l&#039;utilisateur sera bannie.';
$lang['notification_explanation'] = 'Afficher une notification, lorsque quelqu&#039;un se fait bannir ?';
$lang['prefs_email_explanation'] = 'Envoyer un email aux admins, quand quelqu&#039;un se fait bannir ?';
$lang['prefs_email_input_explanation'] = 'Veuillez sp&eacute;cifier les emails &agrave; qui vous souhaitez envoyer l&#039;alerte. Vous pouvez en d&eacute;signer plusieurs en les s&eacute;parant par une virgule.';
$lang['authorized_ip_explanation'] = 'Cette liste est utilis&eacute;e au cas o&ugrave; IPLock fonctionne en mode &quot;Interdire &agrave; tous&quot;.';
$lang['authorized_ip_legend'] = 'Liste des IPs autoris&eacute;es express&eacute;ment';
$lang['add_ip_legend'] = 'Ajouter une nouvelle IP (ou plage) aux exceptions';
$lang['add_current_ip'] = 'Ou ajoutez votre adresse IP actuelle (%s)';
$lang['ip_comment'] = 'Commentaires';
$lang['syntax_legend'] = 'Syntaxe';
$lang['syntax_intro'] = 'Une IP se d&eacute;compose en quatre nombre variant de 0 &agrave; 255. Pour chacun de ces nombres, on peut sp&eacute;cifier :';
$lang['syntax_line1'] = 'Une valeur fixe, entre 0 et 255';
$lang['syntax_line2'] = 'Un plage, en tapant &#039;12-245&#039; par exemple';
$lang['syntax_line3'] = 'Tout nombre accept&eacute;, en tapant &#039;*&#039;';
$lang['prohibited_ip_explanation'] = 'Cette liste est utilis&eacute;e quelque soit le mode. Une IP interdite sera toujours interdite.';
$lang['prohibited_ip_legend'] = 'Liste des IPs interdites express&eacute;ment';
$lang['banned_template'] = 'Template de la page  &quot;Banni&quot;';
$lang['banned_template_legend'] = 'Modifiez le template comme vous le d&eacute;sirez.';
$lang['edit_ip_comment_legend'] = 'R&eacute;digez un commentaire pour l&#039;IP %s';
$lang['help'] = '<h3>Que fait ce module ?</h3>
<p>IPLock filtre les adresses IP ayant le droit de se connecter sur l&#039;interface Admin</p>
<h3>Comment l&#039;utiliser ?</h3>
<p>Apr&egrave;s installation, vous pouvez acc&eacute;der au module IPLock par le panneau d&#039;administration sous le menu &quot;Administration du site&quot;.
Son fonctionnement est pour le reste relativement &eacute;vident, je l&#039;esp&egrave;re</p>
<h3>Permissions</h3>
<p>IPLock ajoute une permission, &quot;Gestion d&#039;IPLock&quot;, et il est n&eacute;cessaire qu&#039;elle soit coch&eacute;e pour pouvoir administrer le blocage d&#039;IP</p>
<h3>Copyright et Licence</h3>
<p>Copyright @ 2010, Beno&icirc;t Vermont - <a href="mailto:redwarp@gmail.com">redwarp@gmail.com</a>. Tous droits r&eacute;serv&eacute;s.</p>
<p>Ce module est distribu&eacute; sous la licence <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. Vous devez agr&eacute;er aux termes de cette licence pour pouvoir utiliser ce module.</p>';
$lang['accessdenied'] = '<h3>Acc&egrave;s refus&eacute;</h3>
<p>&Ecirc;tes vous s&ucirc;r de poss&eacute;der les droits suffisant ? Si oui, contactez votre administrateur afin
qu&#039;il corrige le probl&egrave;me</p>';
$lang['genericerror'] = 'Hohoho. Il semblerai que votre derni&egrave;re op&eacute;ration ai g&eacute;n&eacute;r&eacute; une erreur. &Ecirc;tes vous s&ucirc;rs d&#039;avoir tout fait correctement ?';
$lang['iperror'] = 'L&#039;IP sp&eacute;cifi&eacute;e n&#039;est pas valide.';
$lang['delete'] = 'Supprimer';
$lang['edit'] = 'Editer le commentaire';
$lang['cancel'] = 'Annuler';
$lang['deleteconfirm'] = 'Confirmez la suppression';
$lang['emptylist'] = 'La liste est vide';
$lang['wrongip'] = '%s : IP non autoris&eacute;e';
$lang['add'] = 'Ajouter';
$lang['added_allowed_ip'] = '%s : IP autoris&eacute;e';
$lang['added_denied_ip'] = '%s : IP bannie';
$lang['removed_ip'] = '%s : IP supprim&eacute;e';
$lang['prefs'] = 'Pr&eacute;f&eacute;rences';
$lang['allowed_ip'] = 'IPs autoris&eacute;es';
$lang['denied_ip'] = 'IPs bannies';
$lang['yes'] = 'Oui';
$lang['no'] = 'Non';
$lang['save'] = 'Enregistrer les modifications';
$lang['notification_message'] = 'Quelqu&#039;un s&#039;est fait bannir en se trompant d&#039;identifiants. Visitez le panneau d&#039;administration %s pour effacer cette notification.';
$lang['userbanned_event_desc'] = 'Envoy&eacute; d&egrave;s que quelqu&#039;un se fait bannir.';
$lang['userbanned_event_help_paramh'] = 'Param&egrave;tres';
$lang['userbanned_event_help_param1'] = '&#039;ip&#039; - R&eacute;f&eacute;rence &agrave; l&#039;adresse IP de l&#039;individu banni.';
$lang['userbanned_event_help_param2'] = '&#039;cause&#039; - R&eacute;f&eacute;rence &agrave; l&#039;origine du bannissement. Sa valeur peut &ecirc;tre &#039;admin&#039; ou &#039;auto&#039;';
$lang['alert_email_title'] = 'Alerte IPLock';
$lang['alert_email_info'] = 'Site Internet ';
$lang['alert_email_body'] = 'Quelqu&#039;un, utilisant l&#039;adresse ip %s, s&#039;est fait bannir. Vous devriez probablement aller v&eacute;rifier. Dirigez vous vers votre panneau d&#039;administration pour r&eacute;gler &ccedil;a.';
$lang['qca'] = 'P0-1743174823-1267530476007';
$lang['utmz'] = '156861353.1273683193.59.42.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,43953.0.html|utmcmd=referral';
$lang['utma'] = '156861353.984059321.1267530476.1274083934.1274095182.61';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.2.10.1274095182';
?>
